#-----------------------------------------------------------------------------
#
# Copyright 2005, TIG
#
# Permission to use, copy, modify, and distribute this software for 
# any purpose and without fee is hereby granted, provided something the above
# copyright notice appear in all copies.
#
# THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
#
#-----------------------------------------------------------------------------
#
# Name        : ComponentReporter.rb
#
# Type        : Tool
#
# Description : Makes a report of numbers of all components placed in a model.
#
# Menu Item   : Plugins -> ComponentReporter
# Context-Menu: None
#
# Author      : TIG
#
# Usage       : Pick off the Plugins menu and a report is written into a file 
#		called ComponentReport.cls in the model's folder.  It is readable
#		by Excel and similar spreadsheet programs.
#
# Date        : December 2005
#
# Version     :	1.0			Beta tester (not issued)
#		1.1	13/12/05	First Issue.
#		1.2	14/12/05	Ruby Console no longer auto-opens.
#		1.3	15/12/05	Misc errors corrected...
#
#-----------------------------------------------------------------------------

require 'sketchup.rb'

### do class

class Reporter

### do def

def Reporter::components

   model = Sketchup.active_model
### start undo...
   model.start_operation "undo"
   entities = model.entities
   mname = model.title

### show VCB and status info...
   Sketchup::set_status_text(("COMPONENT REPORTER..." ), SB_PROMPT)
   Sketchup::set_status_text(" ", SB_VCB_LABEL)
   Sketchup::set_status_text(" ", SB_VCB_VALUE)

### check model...
   mpath = Dir::pwd
   if mpath == ""
      UI.beep
      UI.messagebox("Vous devez sauvegarder d'abord votre model\navant de faire un rapport !\nSortie... ")
      return nil
   end
### setup list...
   clist = []
   for c in model.definitions
      if c.count_instances > 0 and c.group? != true ###v1.3
         clist = clist.push([c.name,c.count_instances.to_s])
      end#if
   end#for c 
   clist = clist.sort
###
### if no components exit...
   if not clist[0]
      UI.beep
      UI.messagebox("Aucun Composants valabkes pour faire un rapport!\nExiting... ")
      return nil
   end#if
###
### write to csv file...
   namecsv = mpath + "/" + mname + "-ComponentReport.csv"
   file = File.new(namecsv,"w")
   file.puts("NAME,NUMBER\n\n") ### title
   for c in clist
      file.puts(c[0]+","+c[1])
   end#for c
   file.close
### now txt - tab \t separators...
   nametxt = mpath + "/" + mname + "-ComponentReport.txt"
   file = File.new(nametxt,"w")
   file.puts("NAME\t\tNUMBER\n\n") ### title
   for c in clist
      file.puts(c[0]+"\t"+c[1])
   end#for c
   file.close
###
### say it's done...
   UI.messagebox("Rapport de compoosants ecrit dans: \n\n" + namecsv + "\n   et\n" + nametxt)
###
### commit undo...
   model.commit_operation

end#def components

end#class

### Sketchup.send_action "showRubyPanel:"###v1.2

### do menu

if( not file_loaded?("ComponentReporter.rb") )

    cmd = UI::Command.new("Rapport de composants")  { Reporter.components  }
    cmd.tooltip = "Rapport de composants"
    cmd.menu_text = "Rapport de composants"
    cmd.small_icon = "AdebeoIcon/RapportComppt.png"
    cmd.large_icon = "AdebeoIcon/RapportCompgd.png"
    UI.menu("Plugins").add_item cmd
    toolbar = UI::Toolbar.new "Adebeo_ensemble"
    toolbar = toolbar.add_item cmd
		
end#if

file_loaded("ComponentReporter.rb")

###


